@@ -1,6 +1,6 @@
 package JE::Null;
 
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 
 
 use strict;
@@ -47,7 +47,7 @@ Null stringifies to 'null', and is false as a boolean.
 =cut
 
 #use Carp;
-sub new    { bless \$_[1], $_[0] }
+sub new    { bless \do{my $thing = $_[1]}, $_[0] }
 sub prop   {
 	die "Null has no properties, not even one named $_[1]"
 }
